==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/cs-CZ/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Tento uživatel se může přihlásit',
    'activated_disabled_help_text' => 'Nelze upravit stav aktivace pro svůj vlastní účet.',
    'assets_user'       => 'Majetky přiřazené :name',
    'bulk_update_warn'	=> 'Chystáte se upravit vlastnosti :user_count uživatelů. Nezapomeňte, že pomocí tohoto formuláře nemůžete změnit vlastní atributy uživatele a musíte provádět vlastní úpravy individuálně.',
    'bulk_update_help'	=> 'Tento formulář umožňuje aktualizovat více uživatelů najednou. Vyplňte pouze pole, která potřebujete změnit. Všechna pole, která jsou prázdná, zůstanou nezměněny.',
    'current_assets'    => 'Majetky které jsou v současné době vydány uživateli',
    'clone'             => 'Duplikuj uživatele',
    'contact_user'      => 'Kontakt na :name',
    'edit'              => 'Upravit uživatele',
    'filetype_info'     => 'Povolené přílohy: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Historie:',
    'info'				=> 'Informace',
    'restore_user'		=> 'Klikněte zde pro obnovení.',
    'last_login'        => 'Poslední přihlášení',
    'ldap_config_text'  => 'Nastavení konfigurace LDAP lze nalézt v menu Správce> Nastavení. Vybrané (volitelně) místo bude nastaven pro všechny importované uživatele.',
    'print_assigned'    => 'Vypsat všechna přiřazení',
    'email_assigned'    => 'Odeslat seznam aktuálně přiřazeného majetku',
    'user_notified'     => 'Uživateli byl zaslán e-mail se seznamem aktuálně přiřazeného majetku.',
    'auto_assign_label' => 'Zahrnout tohoto uživatele do automatického přiřazování licencí',
    'auto_assign_help'  => 'Nezahrnout tohoto uživatele do automatického přiřazování licencí',
    'software_user'     => 'Software vydaný pro :name',
    'send_email_help'   => 'Musíte zadat e-mailovou adresu tohoto uživatele pro odeslání přihlašovacích údajů. Odeslání přihlašovacích údajů lze provést pouze při vytvoření uživatele. Hesla jsou zašifrována a nelze je zjistit po tom, co jsou uložena.',
    'view_user'         => 'Zobraz uživatele',
    'usercsv'           => 'CSV soubor',
    'two_factor_admin_optin_help' => 'Vaše současná nastavení administrátora umožňují selektivní vynucení dvoufaktorového ověřování.  ',
    'two_factor_enrolled' => '2FA zařízení přihlášeno ',
    'two_factor_active'   => '2FA aktivní ',
    'user_deactivated'  => 'Uživatel nemá právo k přihlášení',
    'user_activated'  => 'Uživatel se může přihlásit',
    'activation_status_warning' => 'Neměnit stav aktivace',
    'group_memberships_helpblock' => 'Pouze superadmini mohou upravovat členství ve skupině.',
    'superadmin_permission_warning' => 'Pouze superadmini mohou povolit uživateli superadmin přístup.',
    'admin_permission_warning' => 'Pouze uživatelé s právy administrátorů a výše mohou udělit uživatelskému adminovi přístup.',
    'remove_group_memberships' => 'Odebrat členství ve skupině',
    'warning_deletion_information' => 'Chystáte se zaškrtnout VŠECHNY položky od níže uvedených :count uživatelů. Super administrátorská jména jsou zvýrazněna červeně.',
    'update_user_assets_status' => 'Aktualizovat všechny položky pro tyto uživatele na tento stav',
    'checkin_user_properties' => 'Zkontrolujte všechny vlastnosti spojené s těmito uživateli',
    'remote_label'   => 'Toto je vzdálený uživatel',
    'remote'   => 'Vzdálený',
    'remote_help' => 'To může být užitečné, pokud potřebujete filtrovat vzdálené uživatele, kteří nikdy nebo jen zřídka přicházejí do firmy.',
    'not_remote_label' => 'Toto není vzdálený uživatel',
    'vip_label' => 'VIP uživatel',
    'vip_help' => 'To může být užitečné označit důležité lidi ve vašem orgu, pokud byste s nimi chtěli zacházet speciálními způsoby.',
    'create_user' => 'Založit uživatele',
    'create_user_page_explanation' => 'Tyto údaje použijtete pro první přihlášení na stránku.',
    'email_credentials' => 'Poslat přihlašovací údaje',
    'email_credentials_text' => 'Odešle moje přihlašovací údaje na e-mailovou adresu výše',
    'next_save_user' => 'Další: Uložení uživatele',
    'all_assigned_list_generation' => 'Vytvořeno:',
    'email_user_creds_on_create' => 'Poslat tomuto uživateli e-mail s jejich pověřením?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/cs-CZ/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Tento uživatel se může přihlásit',
    'activated_disabled_help_text' => 'Nelze upravit stav aktivace pro svůj vlastní účet.',
    'assets_user'       => 'Majetky přiřazené :name',
    'bulk_update_warn'	=> 'Chystáte se upravit vlastnosti :user_count uživatelů. Nezapomeňte, že pomocí tohoto formuláře nemůžete změnit vlastní atributy uživatele a musíte provádět vlastní úpravy individuálně.',
    'bulk_update_help'	=> 'Tento formulář umožňuje aktualizovat více uživatelů najednou. Vyplňte pouze pole, která potřebujete změnit. Všechna pole, která jsou prázdná, zůstanou nezměněny.',
    'current_assets'    => 'Majetky které jsou v současné době vydány uživateli',
    'clone'             => 'Duplikuj uživatele',
    'contact_user'      => 'Kontakt na :name',
    'edit'              => 'Upravit uživatele',
    'filetype_info'     => 'Povolené přílohy: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Historie:',
    'info'				=> 'Informace',
    'restore_user'		=> 'Klikněte zde pro obnovení.',
    'last_login'        => 'Poslední přihlášení',
    'ldap_config_text'  => 'Nastavení konfigurace LDAP lze nalézt v menu Správce> Nastavení. Vybrané (volitelně) místo bude nastaven pro všechny importované uživatele.',
    'print_assigned'    => 'Vypsat všechna přiřazení',
    'email_assigned'    => 'Odeslat seznam aktuálně přiřazeného majetku',
    'user_notified'     => 'Uživateli byl zaslán e-mail se seznamem aktuálně přiřazeného majetku.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Zahrnout tohoto uživatele do automatického přiřazování licencí',
    'auto_assign_help'  => 'Nezahrnout tohoto uživatele do automatického přiřazování licencí',
    'software_user'     => 'Software vydaný pro :name',
    'send_email_help'   => 'Musíte zadat e-mailovou adresu tohoto uživatele pro odeslání přihlašovacích údajů. Odeslání přihlašovacích údajů lze provést pouze při vytvoření uživatele. Hesla jsou zašifrována a nelze je zjistit po tom, co jsou uložena.',
    'view_user'         => 'Zobraz uživatele',
    'usercsv'           => 'CSV soubor',
    'two_factor_admin_optin_help' => 'Vaše současná nastavení administrátora umožňují selektivní vynucení dvoufaktorového ověřování.  ',
    'two_factor_enrolled' => '2FA zařízení přihlášeno ',
    'two_factor_active'   => '2FA aktivní ',
    'user_deactivated'  => 'Uživatel nemá právo k přihlášení',
    'user_activated'  => 'Uživatel se může přihlásit',
    'activation_status_warning' => 'Neměnit stav aktivace',
    'group_memberships_helpblock' => 'Pouze superadmini mohou upravovat členství ve skupině.',
    'superadmin_permission_warning' => 'Pouze superadmini mohou povolit uživateli superadmin přístup.',
    'admin_permission_warning' => 'Pouze uživatelé s právy administrátorů a výše mohou udělit uživatelskému adminovi přístup.',
    'remove_group_memberships' => 'Odebrat členství ve skupině',
    'warning_deletion_information' => 'Chystáte se zaškrtnout VŠECHNY položky od níže uvedených :count uživatelů. Super administrátorská jména jsou zvýrazněna červeně.',
    'update_user_assets_status' => 'Aktualizovat všechny položky pro tyto uživatele na tento stav',
    'checkin_user_properties' => 'Zkontrolujte všechny vlastnosti spojené s těmito uživateli',
    'remote_label'   => 'Toto je vzdálený uživatel',
    'remote'   => 'Vzdálený',
    'remote_help' => 'To může být užitečné, pokud potřebujete filtrovat vzdálené uživatele, kteří nikdy nebo jen zřídka přicházejí do firmy.',
    'not_remote_label' => 'Toto není vzdálený uživatel',
    'vip_label' => 'VIP uživatel',
    'vip_help' => 'To může být užitečné označit důležité lidi ve vašem orgu, pokud byste s nimi chtěli zacházet speciálními způsoby.',
    'create_user' => 'Založit uživatele',
    'create_user_page_explanation' => 'Tyto údaje použijtete pro první přihlášení na stránku.',
    'email_credentials' => 'Poslat přihlašovací údaje',
    'email_credentials_text' => 'Odešle moje přihlašovací údaje na e-mailovou adresu výše',
    'next_save_user' => 'Další: Uložení uživatele',
    'all_assigned_list_generation' => 'Vytvořeno:',
    'email_user_creds_on_create' => 'Poslat tomuto uživateli e-mail s jejich pověřením?',
];
